Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6)

Unified Diff: src/IceInst.h

Issue 814353002: Subzero: Convert NULL->nullptr. (Closed) Base URL: https://chromium.googlesource.com/native_client/pnacl-subzero.git@master
Patch Set: Revert crosstest whitespace changes Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/IceGlobalContext.cpp ('k') | src/IceInst.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/IceInst.h
diff --git a/src/IceInst.h b/src/IceInst.h
index 0b7dc039ac9a405f0ab528765bf1a3d6594429bc..8dd77eca231f8d9bd2309c4f054636e5a5896653 100644
--- a/src/IceInst.h
+++ b/src/IceInst.h
@@ -321,7 +321,7 @@ public:
static InstBr *create(Cfg *Func, CfgNode *Target) {
return new (Func->allocate<InstBr>()) InstBr(Func, Target);
}
- bool isUnconditional() const { return getTargetTrue() == NULL; }
+ bool isUnconditional() const { return getTargetTrue() == nullptr; }
Operand *getCondition() const {
assert(!isUnconditional());
return getSrc(0);
@@ -346,7 +346,7 @@ private:
~InstBr() override {}
CfgNode *TargetFalse; // Doubles as unconditional branch target
- CfgNode *TargetTrue; // NULL if unconditional branch
+ CfgNode *TargetTrue; // nullptr if unconditional branch
};
// Call instruction. The call target is captured as getSrc(0), and
@@ -615,7 +615,7 @@ class InstRet : public InstHighLevel {
InstRet &operator=(const InstRet &) = delete;
public:
- static InstRet *create(Cfg *Func, Operand *RetValue = NULL) {
+ static InstRet *create(Cfg *Func, Operand *RetValue = nullptr) {
return new (Func->allocate<InstRet>()) InstRet(Func, RetValue);
}
bool hasRetValue() const { return getSrcSize(); }
@@ -760,7 +760,8 @@ class InstFakeDef : public InstHighLevel {
InstFakeDef &operator=(const InstFakeDef &) = delete;
public:
- static InstFakeDef *create(Cfg *Func, Variable *Dest, Variable *Src = NULL) {
+ static InstFakeDef *create(Cfg *Func, Variable *Dest,
+ Variable *Src = nullptr) {
return new (Func->allocate<InstFakeDef>()) InstFakeDef(Func, Dest, Src);
}
void emit(const Cfg *Func) const override;
« no previous file with comments | « src/IceGlobalContext.cpp ('k') | src/IceInst.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698